@@ -1,11 +1,11 @@
 package Log::Any::For::STDERR;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 use Log::Any;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our $Prefix = $ENV{LOG_STDERR_PREFIX} // "STDERR: ";
 
@@ -43,7 +43,7 @@ Log::Any::For::STDERR - (DEPRECATED) Send output of STDERR to Log::Any
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -58,7 +58,8 @@ L<Log::Any::Adapter::ScreenColoredLevel> also outputs to STDERR which prevents
 this module from working properly. To trap warnings and error messages from
 Perl, you can instead try installing a C<$SIG{__WARN__}> and C<$SIG{__DIE__}>
 handler. To capture all STDERR output (including from external programs), you
-might want to wrap your Perl script and redirect its output.
+might want to wrap your Perl script and redirect its output; try
+L<Process::Govern>.
 
 This module will send output of STDERR to Log::Any. Messages are logged at
 C<warn> level in category C<STDERR>. Messages produced by warn() and print(),
@@ -88,7 +89,9 @@ To log other stuffs to Log::Any (besides the normal way of C<< $log->debug() >>
 et al, that is), see various other Log::Any::For::* modules.
 
 To capture STDERR there are various ways, including those that utilizes fork and
-can capture output of external programs. For example, see L<Capture::Tiny>.
+can capture output of external programs. For example, see L<Capture::Tiny>. Also
+see L<Process::Govern> which, aside from capturing output, also governs other
+aspects of child process.
 
 =head1 AUTHOR
 
@@ -96,7 +99,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
